@@ -183,7 +183,12 @@ def clean_up():
     #           # Log the standard error if it is not empty
     #           sys.stderr.write(stderr)
 
-    # Delete folder containing temporary Jackhmmer database chunks
+    # Delete any fasta files left in temporary jackhmmer folder
+    for file in glob.glob(os.path.expanduser(f"~/tmp/jackhmmer/{UUID}/*.fasta")):
+        if os.path.exists(file):
+            os.remove(file)
+
+    # Delete empty parent folders
     os.removedirs(os.path.expanduser(f"~/tmp/jackhmmer/{UUID}"))
 
 
@@ -489,6 +494,12 @@ def alphafold(
     if out is not None:
         os.makedirs(out, exist_ok=True)
         abs_out_path = os.path.abspath(out)
+    else:
+        # Use temporary jackhmmer folder which will later be deleted
+        abs_out_path = os.path.expanduser(f"~/tmp/jackhmmer/{UUID}")
+
+    # Create folder to save temporary jackhmmer database chunks in
+    os.makedirs(os.path.expanduser(f"~/tmp/jackhmmer/{UUID}"), exist_ok=True)
 
     features_for_chain = {}
     raw_msa_results_for_sequence = {}
@@ -496,9 +507,6 @@ def alphafold(
 
         # logging.info(f"Getting MSA for sequence {sequence_index}.")
 
-        # Create folder to save temporary jackhmmer database chunks in
-        os.makedirs(os.path.expanduser(f"~/tmp/jackhmmer/{UUID}"), exist_ok=True)
-
         ## Manage permissions to jackhmmer binary
         command = f"chmod 755 {JACKHMMER_BINARY_PATH}"
         with subprocess.Popen(command, shell=True, stderr=subprocess.PIPE) as process:
