@@ -33,6 +33,7 @@ from .gget_archs4 import archs4
 from .gget_alphafold import alphafold
 from .gget_setup import setup
 from .gget_pdb import pdb
+from .gget_gpt import gpt
 
 
 def main():
@@ -259,7 +260,15 @@ def main():
         type=str,
         nargs="*",
         default=None,
-        help="One or more Ensembl, WormBase or FlyBase IDs).",
+        help="One or more Ensembl, WormBase or FlyBase IDs.",
+    )
+    parser_info.add_argument(
+        "-pdb",
+        "--pdb",
+        default=False,
+        action="store_true",
+        required=False,
+        help="Also returns PDB IDs (might increase run time).",
     )
     parser_info.add_argument(
         "-eo",
@@ -267,7 +276,7 @@ def main():
         default=False,
         action="store_true",
         required=False,
-        help="Only return results from Ensembl.",
+        help="Only returns results from Ensembl (excludes PDB, UniProt, and NCBI results).",
     )
     parser_info.add_argument(
         "-csv",
@@ -283,7 +292,7 @@ def main():
         default=True,
         action="store_false",
         required=False,
-        help="Do not print progress information.",
+        help="Does not print progress information.",
     )
     parser_info.add_argument(
         "-o",
@@ -959,6 +968,98 @@ def main():
         ),
     )
 
+    # gpt parser arguments
+    gpt_desc = "Generates natural language text based on a given prompt using the OpenAI API's 'openai.ChatCompletion.create' endpoint."
+    parser_gpt = parent_subparsers.add_parser(
+        "gpt",
+        parents=[parent],
+        description=gpt_desc,
+        help=gpt_desc,
+        add_help=True,
+    )
+    parser_gpt.add_argument(
+        "prompt",
+        type=str,
+        help="The input prompt to generate text from.",
+    )
+    parser_gpt.add_argument(
+        "api_key",
+        type=str,
+        help="Your OpenAI API key (see: https://platform.openai.com/account/api-keys)",
+    )
+    parser_gpt.add_argument(
+        "-m",
+        "--model",
+        type=str,
+        default="gpt-3.5-turbo",
+        required=False,
+        help="The name of the GPT model to use (defaults to 'gpt-3.5-turbo') (see: https://platform.openai.com/docs/models/gpt-4)",
+    )
+    parser_gpt.add_argument(
+        "-temp",
+        "--temperature",
+        type=float,
+        default=1,
+        required=False,
+        help="Value between 0 and 2.0 that controls the level of randomness and creativity in the generated text.",
+    )
+    parser_gpt.add_argument(
+        "-tp",
+        "--top_p",
+        type=float,
+        default=1,
+        required=False,
+        help="Controls the diversity of the generated text as an alternative to sampling with temperature.",
+    )
+    parser_gpt.add_argument(
+        "-s",
+        "--stop",
+        type=str,
+        default=None,
+        required=False,
+        help="A sequence of tokens to mark the end of the generated text.",
+    )
+    parser_gpt.add_argument(
+        "-mt",
+        "--max_tokens",
+        type=int,
+        default=200,
+        required=False,
+        help="Controls the maximum length of the generated text, in tokens.",
+    )
+    parser_gpt.add_argument(
+        "-pp",
+        "--presence_penalty",
+        type=float,
+        default=0,
+        required=False,
+        help="Number between -2.0 and 2.0. Higher values result increase the model's likelihood to talk about new topics.",
+    )
+    parser_gpt.add_argument(
+        "-fp",
+        "--frequency_penalty",
+        type=float,
+        default=0,
+        required=False,
+        help="Number between -2.0 and 2.0. Higher values decrease the model's likelihood to repeat the same line verbatim.",
+    )
+    parser_gpt.add_argument(
+        "-lb",
+        "--logit_bias",
+        type=dict,
+        default=None,
+        required=False,
+        help="A dictionary that specifies a bias towards certain tokens in the generated text.",
+    )
+    parser_gpt.add_argument(
+        "-o",
+        "--out",
+        type=str,
+        default=None,
+        required=False,
+        help="The file name to save the generated text to as a text file (defaults to printing the output to the console)",
+    )
+
     ### Define return values
     args = parent_parser.parse_args()
 
@@ -989,15 +1090,19 @@ def main():
 
     # Show  module specific help if only module but no further arguments are given
     command_to_parser = {
-        "muscle": parser_muscle,
         "ref": parser_ref,
         "search": parser_gget,
-        "seq": parser_seq,
         "info": parser_info,
+        "seq": parser_seq,
+        "muscle": parser_muscle,
         "blast": parser_blast,
         "blat": parser_blat,
         "enrichr": parser_enrichr,
         "archs4": parser_archs4,
+        "setup": parser_setup,
+        "alphafold": parser_alphafold,
+        "pdb": parser_pdb,
+        "gpt": parser_gpt,
     }
 
     if len(sys.argv) == 2:
@@ -1007,6 +1112,25 @@ def main():
             parent_parser.print_help(sys.stderr)
         sys.exit(1)
 
+    ## gpt return
+    if args.command == "gpt":
+        gpt_results = gpt(
+            prompt=args.prompt,
+            api_key=args.api_key,
+            model=args.model,
+            temperature=args.temperature,
+            top_p=args.top_p,
+            stop=args.stop,
+            max_tokens=args.max_tokens,
+            presence_penalty=args.presence_penalty,
+            frequency_penalty=args.frequency_penalty,
+            logit_bias=args.logit_bias,
+            out=args.out,
+        )
+
+        if args.out is None:
+            sys.stdout.write(gpt_results)
+
     ## blat return
     if args.command == "blat":
         # Handle deprecated flags for backwards compatibility
@@ -1451,6 +1575,7 @@ def main():
         # Look up requested Ensembl IDs
         info_results = info(
             ids_clean_final,
+            pdb=args.pdb,
             ensembl_only=args.ensembl_only,
             expand=args.expand,
             json=args.csv,
